@@ -10,21 +10,27 @@ class Database:
             print("Failed creating database: {}".format(err))
 
     def __init__(self):
-        user = os.environ.get('MYSQL_USER', 'prod')
-        password = os.environ.get('MYSQL_PASSWORD', 'prod')
-        host = os.environ.get('MYSQL_HOST', '127.0.0.1')
-        database = os.environ.get('MYSQL_DATABASE', 'axiom')
-        charset = os.environ.get('MYSQL_CHARSET', 'utf8')
+        self.user = os.environ.get('MYSQL_USER', 'prod')
+        self.password = os.environ.get('MYSQL_PASSWORD', 'prod')
+        self.host = os.environ.get('MYSQL_HOST', '127.0.0.1')
+        self.database = os.environ.get('MYSQL_DATABASE', 'axiom')
+        self.charset = os.environ.get('MYSQL_CHARSET', 'utf8')
         try:
-            self.conn = mysql.connector.connect(user=user, password=password, host=host, database=database)
+            self.conn = mysql.connector.connect(**self.kwargs)
         except mysql.connector.errors.ProgrammingError as err:
             print(err.msg)
             m = re.compile("Unknown database '(\w+)'").search(err.msg)
             assert m
-            assert m[1] == database
-            self.conn = mysql.connector.connect(user=user, password=password, host=host, database='mysql')
-            self.execute("create database " + database)
-            self.conn = mysql.connector.connect(user=user, password=password, host=host, database=database)
+            assert m[1] == self.database
+            kwargs = self.kwargs
+            kwargs['database'] = 'mysql'
+            self.conn = mysql.connector.connect(**kwargs)
+            self.execute("create database " + self.database)
+            self.conn = mysql.connector.connect(**self.kwargs)
+
+    @property
+    def kwargs(self):
+        return dict(user=self.user, password=self.password, host=self.host, database=self.database, charset=self.charset)
 
     def cursor(self, **kwargs):
         return self.conn.cursor(**kwargs)
@@ -109,13 +115,22 @@ class Database:
     def desc_table(self, table):
         return [*self.query("desc %s" % table)]
 
+    def __enter__(self):
+        if self.conn is None:
+            self.conn = mysql.connector.connect(**self.kwargs)
+        return self
+
+    def __exit__(self, *args):
+        self.conn.close()
+        self.conn = None 
+
 
 class MySQLConnector(Database):
 
     def __init__(self):
         Database.__init__(self)
         
-    def load_data_from_list(self, table, array, step=10000, replace=False, ignore=False, truncate=False):
+    def load_data_from_list(self, table, array, step=10000, replace=False, ignore=True, truncate=False):
         desc = self.desc_table(table)
         
         has_training_field = False
@@ -151,6 +166,8 @@ class MySQLConnector(Database):
                     for args in lines[i:i + step]: 
                         if isinstance(args, tuple):
                             args = [*args]
+                        elif isinstance(args, dict):
+                            args = [args.get(Field, '') for Field, *_ in desc]
                             
                         for i, arg in enumerate(args):
                             if isinstance(arg, set):
@@ -167,7 +184,9 @@ class MySQLConnector(Database):
                                     print('args[%d] exceeds the allowable length %d' % (i, char_length[i]))
                                     arg = arg[:char_length[i]]
                                     
-                                arg = arg.decode()                                
+                                arg = arg.decode()
+                            elif isinstance(arg, dict):
+                                arg = std.json_encode(std.json_encode(arg))[1:-1]
                             else:
                                 arg = str(arg)
                             
