@@ -753,12 +753,12 @@ def fromEntries(*args, object=True):
     return obj
 
 
-def array_split(arr, index):
-    if isinstance(index, int):
-        return arr[:index], arr[index:]
+def array_split(self, pivot):
+    if isinstance(pivot, int):
+        return self[:pivot], self[pivot:]
     
-    if isinstance(index, slice):
-        start, stop, step = index.start, index.stop, index.step
+    if isinstance(pivot, slice):
+        start, stop, step = pivot.start, pivot.stop, pivot.step
         if step is None:
             step = 1
 
@@ -766,38 +766,47 @@ def array_split(arr, index):
             if start is None:
                 start = 0
             elif start < 0:
-                start += len(arr)
+                start += len(self)
 
             if stop is None:
-                stop = len(arr)
+                stop = len(self)
             elif stop < 0:
-                stop += len(arr)
+                stop += len(self)
 
             if step > 1:
-                rest = (arr[i] for i in {*range(start, stop)} - {*range(start, stop, step)})
-                rest = arr[:start] + type(arr)(rest) + arr[stop:]
+                rest = (self[i] for i in {*range(start, stop)} - {*range(start, stop, step)})
+                rest = self[:start] + type(self)(rest) + self[stop:]
             else:
-                rest = arr[:start] + arr[stop:]
+                rest = self[:start] + self[stop:]
                 
-            return arr[index], rest
+            return self[pivot], rest
         else:
             if start is None:
-                start = len(arr) - 1
+                start = len(self) - 1
             elif start < 0:
-                start += len(arr)
+                start += len(self)
 
             if stop is None:
                 stop = -1
             elif stop < -1:
-                stop += len(arr)
+                stop += len(self)
             
             if step < -1:
-                rest = (arr[i] for i in {*range(start, stop, -1)} - {*range(start, stop, step)})
-                rest = arr[:stop + 1] + type(arr)(rest) + arr[start + 1:]
+                rest = (self[i] for i in {*range(start, stop, -1)} - {*range(start, stop, step)})
+                rest = self[:stop + 1] + type(self)(rest) + self[start + 1:]
             else:
-                rest = arr[:stop + 1] + arr[start + 1:]
+                rest = self[:stop + 1] + self[start + 1:]
 
-            return rest, arr[index] 
+            return rest, self[pivot] 
+
+    former = []
+    latter = []
+    for arg in self:
+        if pivot(arg):
+            former.append(arg)
+        else:
+            latter.append(arg)
+    return former, latter
 
 
 if __name__ == '__main__':
